#ifndef __SD_SKIN_H__
#define __SD_SKIN_H__

#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtk.h>

class _Skin_cursor
{
public:
	GdkCursor *cursor;
	_Skin_cursor::_Skin_cursor();
	_Skin_cursor::~_Skin_cursor();
};

struct _Skin_pixbuf_1
{
	GdkPixbuf *p[1];
	_Skin_pixbuf_1();
	~_Skin_pixbuf_1();
};

struct _Skin_stardict
{
	int width,height;
	struct _Skin_cursor normal_cursor;
	struct _Skin_cursor watch_cursor;
	struct _Skin_pixbuf_1 icon;
#ifndef _WIN32
	struct _Skin_pixbuf_1 docklet_normal_icon;
	struct _Skin_pixbuf_1 docklet_scan_icon;
	struct _Skin_pixbuf_1 docklet_stop_icon;
#endif
	struct _Skin_pixbuf_1 index_wazard;
	struct _Skin_pixbuf_1 index_appendix;
};

class AppSkin
{
public:
	AppSkin();	
	struct _Skin_stardict stardict;
	
	void load();
private:
	
};

#endif
